← Back to team overview

launchpad-reviewers team mailing list archive

[Merge] lp:~wallyworld/launchpad/security-informationtype-terminology into lp:launchpad

 

Ian Booth has proposed merging lp:~wallyworld/launchpad/security-informationtype-terminology into lp:launchpad with lp:~wallyworld/launchpad/information-type-verbosity-1015509 as a prerequisite.

Requested reviews:
  Curtis Hovey (sinzui)
Related bugs:
  Bug #1015509 in Launchpad itself: "Embargoed box is far too wordy"
  https://bugs.launchpad.net/launchpad/+bug/1015509

For more details, see:
https://code.launchpad.net/~wallyworld/launchpad/security-informationtype-terminology/+merge/115278

Change the text for InformationType enums.

Unembargoed Security -> Public Security
Embargoed Security -> Private Security

This fits better with user expectations since reports are that they are confused by what Embargoed Security means.

I also changed the enum values to PUBLICSECURITY and PRIVATESECURITY for consistency.
-- 
https://code.launchpad.net/~wallyworld/launchpad/security-informationtype-terminology/+merge/115278
Your team Launchpad code reviewers is subscribed to branch lp:launchpad.
=== modified file 'database/schema/patch-2209-11-4.sql'
--- database/schema/patch-2209-11-4.sql	2012-03-20 05:46:50 +0000
+++ database/schema/patch-2209-11-4.sql	2012-07-17 06:39:20 +0000
@@ -18,7 +18,7 @@
 BEGIN
     SELECT * INTO bug_row FROM bug WHERE id = bug_id;
     SELECT id INTO artifact_id FROM AccessArtifact WHERE bug = bug_id;
-    -- 3 == EMBARGOEDSECURITY, 4 == USERDATA, 5 == PROPRIETARY
+    -- 3 == PRIVATESECURITY, 4 == USERDATA, 5 == PROPRIETARY
     IF bug_row.information_type NOT IN (3, 4, 5) THEN
         IF artifact_id IS NOT NULL THEN
             -- Bug is public, but there are access control rows. Destroy them.

=== modified file 'database/schema/patch-2209-16-0.sql'
--- database/schema/patch-2209-16-0.sql	2012-03-29 23:58:58 +0000
+++ database/schema/patch-2209-16-0.sql	2012-07-17 06:39:20 +0000
@@ -224,7 +224,7 @@
 BEGIN
     -- If the bug is private, grab the access control information.
     -- If the bug is public, access_policies and access_grants are NULL.
-    -- 3 == EMBARGOEDSECURITY, 4 == USERDATA, 5 == PROPRIETARY
+    -- 3 == PRIVATESECURITY, 4 == USERDATA, 5 == PROPRIETARY
     IF information_type IN (3, 4, 5) THEN
         SELECT id INTO _access_artifact
             FROM accessartifact

=== modified file 'database/schema/patch-2209-16-6.sql'
--- database/schema/patch-2209-16-6.sql	2012-06-15 05:49:38 +0000
+++ database/schema/patch-2209-16-6.sql	2012-07-17 06:39:20 +0000
@@ -20,7 +20,7 @@
 BEGIN
     -- If private, grab the access control information.
     -- If public, access_policies and access_grants are NULL.
-    -- 3 == EMBARGOEDSECURITY, 4 == USERDATA, 5 == PROPRIETARY
+    -- 3 == PRIVATESECURITY, 4 == USERDATA, 5 == PROPRIETARY
     IF information_type IN (3, 4, 5) THEN
         SELECT COALESCE(array_agg(policy ORDER BY policy), ARRAY[]::integer[])
             INTO _policies FROM accesspolicyartifact WHERE artifact = art_id;

=== modified file 'lib/lp/bugs/adapters/bug.py'
--- lib/lp/bugs/adapters/bug.py	2012-03-26 04:57:50 +0000
+++ lib/lp/bugs/adapters/bug.py	2012-07-17 06:39:20 +0000
@@ -36,9 +36,9 @@
 
 def convert_to_information_type(private, security_related):
     if private and security_related:
-        return InformationType.EMBARGOEDSECURITY
+        return InformationType.PRIVATESECURITY
     elif security_related:
-        return InformationType.UNEMBARGOEDSECURITY
+        return InformationType.PUBLICSECURITY
     elif private:
         return InformationType.USERDATA
     else:

=== modified file 'lib/lp/bugs/browser/bugtarget.py'
--- lib/lp/bugs/browser/bugtarget.py	2012-07-17 06:39:20 +0000
+++ lib/lp/bugs/browser/bugtarget.py	2012-07-17 06:39:20 +0000
@@ -650,7 +650,7 @@
             # If the old UI is enabled, security bugs are always embargoed
             # when filed, but can be disclosed after they've been reported.
             if security_related:
-                information_type = InformationType.EMBARGOEDSECURITY
+                information_type = InformationType.PRIVATESECURITY
             else:
                 information_type = InformationType.PUBLIC
 

=== modified file 'lib/lp/bugs/browser/tests/test_bugtarget_filebug.py'
--- lib/lp/bugs/browser/tests/test_bugtask.py	2012-07-17 06:39:20 +0000
+++ lib/lp/bugs/browser/tests/test_bugtask.py	2012-07-17 06:39:20 +0000
@@ -1940,7 +1940,7 @@
     if bugtask is None:
         owner = factory.makePerson()
         bug = factory.makeBug(
-            owner=owner, information_type=InformationType.EMBARGOEDSECURITY)
+            owner=owner, information_type=InformationType.PRIVATESECURITY)
         with person_logged_in(owner):
             bugtask = bug.default_bugtask
     else:

=== modified file 'lib/lp/bugs/browser/tests/test_bugview.py'
--- lib/lp/bugs/browser/tests/test_bugview.py	2012-07-17 06:39:20 +0000
+++ lib/lp/bugs/browser/tests/test_bugview.py	2012-07-17 06:39:20 +0000
@@ -71,7 +71,7 @@
             InformationType.USERDATA, self.bug.owner)
         self.assertEqual('sprite private', self.view.information_type_css)
         self.bug.transitionToInformationType(
-            InformationType.UNEMBARGOEDSECURITY, self.bug.owner)
+            InformationType.PUBLICSECURITY, self.bug.owner)
         self.assertEqual('sprite public', self.view.information_type_css)
 
     def test_proprietary_excluded_for_normal_projects(self):
@@ -85,8 +85,8 @@
         cache = IJSONRequestCache(view.request)
         expected = [
             InformationType.PUBLIC.name,
-            InformationType.UNEMBARGOEDSECURITY.name,
-            InformationType.EMBARGOEDSECURITY.name,
+            InformationType.PUBLICSECURITY.name,
+            InformationType.PRIVATESECURITY.name,
             InformationType.USERDATA.name]
         self.assertContentEqual(expected, [
             type['value']
@@ -103,8 +103,8 @@
         cache = IJSONRequestCache(view.request)
         expected = [
             InformationType.PUBLIC.name,
-            InformationType.UNEMBARGOEDSECURITY.name,
-            InformationType.EMBARGOEDSECURITY.name,
+            InformationType.PUBLICSECURITY.name,
+            InformationType.PRIVATESECURITY.name,
             InformationType.USERDATA.name,
             InformationType.PROPRIETARY.name]
         self.assertContentEqual(expected, [

=== modified file 'lib/lp/bugs/doc/bug-private-by-default.txt'
--- lib/lp/bugs/doc/bug-private-by-default.txt	2012-03-23 06:10:28 +0000
+++ lib/lp/bugs/doc/bug-private-by-default.txt	2012-07-17 06:39:20 +0000
@@ -47,7 +47,7 @@
     >>> security_bug_params = CreateBugParams(
     ...     owner=no_priv, title='Security bug',
     ...     comment='A monkey took my GPG keys.',
-    ...     information_type=InformationType.EMBARGOEDSECURITY)
+    ...     information_type=InformationType.PRIVATESECURITY)
     >>> security_bug = landscape.createBug(security_bug_params)
     >>> [security_bug_task] = security_bug.bugtasks
     >>> security_bug_task.bug.private

=== modified file 'lib/lp/bugs/doc/bugnotification-email.txt'
--- lib/lp/bugs/doc/bugnotification-email.txt	2012-04-28 09:24:23 +0000
+++ lib/lp/bugs/doc/bugnotification-email.txt	2012-07-17 06:39:20 +0000
@@ -95,7 +95,7 @@
 New security related bugs are sent with a prominent warning:
 
     >>> changed = bug_four.transitionToInformationType(
-    ...     InformationType.UNEMBARGOEDSECURITY, getUtility(ILaunchBag).user)
+    ...     InformationType.PUBLICSECURITY, getUtility(ILaunchBag).user)
 
     >>> subject, body = generate_bug_add_email(bug_four)
     >>> subject
@@ -111,7 +111,7 @@
 Security related bugs can be embargoed:
 
     >>> bug_four.transitionToInformationType(
-    ...     InformationType.EMBARGOEDSECURITY, getUtility(ILaunchBag).user)
+    ...     InformationType.PRIVATESECURITY, getUtility(ILaunchBag).user)
     True
 
     >>> subject, body = generate_bug_add_email(bug_four)
@@ -227,7 +227,7 @@
 
     >>> edited_bug = getUtility(IBugSet).get(6)
     >>> edited_bug.transitionToInformationType(
-    ...     InformationType.EMBARGOEDSECURITY, getUtility(ILaunchBag).user)
+    ...     InformationType.PRIVATESECURITY, getUtility(ILaunchBag).user)
     True
     >>> bug_delta = BugDelta(
     ...     bug=edited_bug,
@@ -531,7 +531,7 @@
     Sender: bounces@xxxxxxxxxxxxx
     X-Launchpad-Bug: product=firefox; ...; assignee=None;
     X-Launchpad-Bug-Tags: bar foo
-    X-Launchpad-Bug-Information-Type: Embargoed Security
+    X-Launchpad-Bug-Information-Type: Private Security
     X-Launchpad-Bug-Private: yes
     X-Launchpad-Bug-Security-Vulnerability: yes
     X-Launchpad-Bug-Commenters: name12

=== modified file 'lib/lp/bugs/doc/bugnotification-sending.txt'
--- lib/lp/bugs/doc/bugnotification-sending.txt	2012-07-17 06:39:20 +0000
+++ lib/lp/bugs/doc/bugnotification-sending.txt	2012-07-17 06:39:20 +0000
@@ -419,7 +419,7 @@
     ...     sec_vuln_bug = ubuntu.createBug(CreateBugParams(
     ...         msg=sec_vuln_description, owner=sample_person,
     ...         title='Zero-day on Frobulator',
-    ...         information_type=InformationType.EMBARGOEDSECURITY))
+    ...         information_type=InformationType.PRIVATESECURITY))
 
     >>> notifications = (
     ...     getUtility(IBugNotificationSet).getNotificationsToSend())
@@ -768,16 +768,16 @@
 
     >>> with lp_dbuser():
     ...     bug_three.transitionToInformationType(
-    ...         InformationType.EMBARGOEDSECURITY, getUtility(ILaunchBag).user)
+    ...         InformationType.PRIVATESECURITY, getUtility(ILaunchBag).user)
     True
     >>> print bug_three.information_type.title
-    Embargoed Security
+    Private Security
 
     >>> for message in trigger_and_get_email_messages(bug_three):
     ...     print_message_header_details(message)
-    foo.bar@xxxxxxxxxxxxx ['yes'] ['yes'] ['Embargoed Security']
-    mark@xxxxxxxxxxx ['yes'] ['yes']  ['Embargoed Security']
-    test@xxxxxxxxxxxxx ['yes'] ['yes']  ['Embargoed Security']
+    foo.bar@xxxxxxxxxxxxx ['yes'] ['yes'] ['Private Security']
+    mark@xxxxxxxxxxx ['yes'] ['yes']  ['Private Security']
+    test@xxxxxxxxxxxxx ['yes'] ['yes']  ['Private Security']
 
 
 The X-Launchpad-Bug-Commenters header

=== modified file 'lib/lp/bugs/doc/bugsubscription.txt'
--- lib/lp/bugs/doc/bugsubscription.txt	2012-04-26 15:42:42 +0000
+++ lib/lp/bugs/doc/bugsubscription.txt	2012-07-17 06:39:20 +0000
@@ -701,7 +701,7 @@
 
     >>> params = CreateBugParams(
     ...     title="a test bug", comment="a test description",
-    ...     owner=foobar, information_type=InformationType.EMBARGOEDSECURITY)
+    ...     owner=foobar, information_type=InformationType.PRIVATESECURITY)
     >>> new_bug = ubuntu.createBug(params)
 
     >>> getSubscribers(new_bug)
@@ -789,7 +789,7 @@
 
     >>> params = CreateBugParams(
     ...     title="a test bug", comment="a test description",
-    ...     owner=foobar, information_type=InformationType.EMBARGOEDSECURITY)
+    ...     owner=foobar, information_type=InformationType.PRIVATESECURITY)
     >>> new_bug = firefox.createBug(params)
 
     >>> getSubscribers(new_bug)
@@ -855,7 +855,7 @@
     >>> params = CreateBugParams(
     ...     title="yet another test bug",
     ...     comment="yet another test description",
-    ...     owner=foobar, information_type=InformationType.EMBARGOEDSECURITY)
+    ...     owner=foobar, information_type=InformationType.PRIVATESECURITY)
     >>> new_bug = evolution.createBug(params)
 
     >>> getSubscribers(new_bug)

=== modified file 'lib/lp/bugs/doc/security-teams.txt'
--- lib/lp/bugs/doc/security-teams.txt	2012-05-22 12:05:51 +0000
+++ lib/lp/bugs/doc/security-teams.txt	2012-07-17 06:39:20 +0000
@@ -50,7 +50,7 @@
     ...     owner=getUtility(ILaunchBag).user,
     ...     title="a security bug",
     ...     comment="this is an example security bug",
-    ...     information_type=InformationType.EMBARGOEDSECURITY)
+    ...     information_type=InformationType.PRIVATESECURITY)
     >>> bug = ubuntu.createBug(params)
 
     >>> bug.security_related
@@ -96,7 +96,7 @@
     ...     owner=getUtility(ILaunchBag).user,
     ...     title="another security bug",
     ...     comment="this is another security bug",
-    ...     information_type=InformationType.EMBARGOEDSECURITY)
+    ...     information_type=InformationType.PRIVATESECURITY)
     >>> bug = firefox.createBug(params)
 
     >>> bug.security_related
@@ -135,7 +135,7 @@
     ...     owner=getUtility(ILaunchBag).user,
     ...     title="another security bug",
     ...     comment="this is another security bug",
-    ...     information_type=InformationType.EMBARGOEDSECURITY)
+    ...     information_type=InformationType.PRIVATESECURITY)
 
     >>> bug = firefox.createBug(params)
 
@@ -191,7 +191,7 @@
     ...     owner=getUtility(ILaunchBag).user,
     ...     title="another security bug",
     ...     comment="this is private security bug",
-    ...     information_type=InformationType.EMBARGOEDSECURITY)
+    ...     information_type=InformationType.PRIVATESECURITY)
     >>> bug = firefox.createBug(params)
 
     >>> bug.security_related

=== modified file 'lib/lp/bugs/javascript/tests/test_filebug.html'
--- lib/lp/bugs/javascript/tests/test_filebug.html	2012-07-17 06:39:20 +0000
+++ lib/lp/bugs/javascript/tests/test_filebug.html	2012-07-17 06:39:20 +0000
@@ -78,16 +78,16 @@
               <td><label for="field.information_type.0">Public</label></td>
             </tr>
             <tr>
-              <td><input type="radio" value="UNEMBARGOEDSECURITY" name="field.information_type"
+              <td><input type="radio" value="PUBLICSECURITY" name="field.information_type"
                 id="field.information_type.1"class="radioType">
               </td>
-              <td><label for="field.information_type.1">Unembargoed Security</label></td>
+              <td><label for="field.information_type.1">Public Security</label></td>
             </tr>
             <tr>
-              <td><input type="radio" value="EMBARGOEDSECURITY" name="field.information_type"
+              <td><input type="radio" value="PRIVATESECURITY" name="field.information_type"
                 id="field.information_type.2"class="radioType">
               </td>
-              <td><label for="field.information_type.2">Embargoed Security</label></td>
+              <td><label for="field.information_type.2">Private Security</label></td>
             </tr>
             <tr>
               <td><input type="radio" value="USERDATA" name="field.information_type"

=== modified file 'lib/lp/bugs/javascript/tests/test_filebug.js'
--- lib/lp/bugs/javascript/tests/test_filebug.js	2012-07-17 06:39:20 +0000
+++ lib/lp/bugs/javascript/tests/test_filebug.js	2012-07-17 06:39:20 +0000
@@ -13,12 +13,12 @@
             window.LP = {
                 links: {},
                 cache: {
-                    private_types: ['EMBARGOEDSECURITY', 'USERDATA'],
+                    private_types: ['PRIVATESECURITY', 'USERDATA'],
                     information_type_data: [
                         {name: 'Public', value: 'PUBLIC',
                             description: 'Public bug'},
-                        {name: 'Embargoed Security',
-                            value: 'EMBARGOEDSECURITY',
+                        {name: 'Private Security',
+                            value: 'PRIVATESECURITY',
                             description: 'Embargoed security bug'},
                         {name: 'Private User', value: 'USERDATA',
                             description: 'Private bug'}
@@ -91,7 +91,7 @@
             Y.Assert.isNull(banner_hidden);
             var banner_text = Y.one('.banner-text').get('text');
             Y.Assert.areEqual(
-                'This report has Embargoed Security information. ' +
+                'This report has Private Security information. ' +
                 'You can change the information type later.', banner_text);
         },
 

=== modified file 'lib/lp/bugs/mail/commands.py'
--- lib/lp/bugs/mail/commands.py	2012-06-29 08:40:05 +0000
+++ lib/lp/bugs/mail/commands.py	2012-07-17 06:39:20 +0000
@@ -190,7 +190,7 @@
                 context.information_type = InformationType.USERDATA
             elif (
                 context.information_type !=
-                InformationType.EMBARGOEDSECURITY):
+                InformationType.PRIVATESECURITY):
                 context.information_type = InformationType.PUBLIC
             return context, current_event
 
@@ -245,7 +245,7 @@
 
         if isinstance(context, CreateBugParams):
             if security_related:
-                context.information_type = InformationType.EMBARGOEDSECURITY
+                context.information_type = InformationType.PRIVATESECURITY
             return context, current_event
 
         # Take a snapshot.

=== modified file 'lib/lp/bugs/mail/tests/test_commands.py'
--- lib/lp/bugs/mail/tests/test_commands.py	2012-05-04 00:03:07 +0000
+++ lib/lp/bugs/mail/tests/test_commands.py	2012-07-17 06:39:20 +0000
@@ -377,13 +377,13 @@
         login_person(user)
         bug_params = CreateBugParams(
             title='bug title', owner=user,
-            information_type=InformationType.EMBARGOEDSECURITY)
+            information_type=InformationType.PRIVATESECURITY)
         command = PrivateEmailCommand('private', ['no'])
         dummy_event = object()
         params, event = command.execute(bug_params, dummy_event)
         self.assertEqual(bug_params, params)
         self.assertEqual(
-            InformationType.EMBARGOEDSECURITY, bug_params.information_type)
+            InformationType.PRIVATESECURITY, bug_params.information_type)
         self.assertEqual(dummy_event, event)
 
 
@@ -409,7 +409,7 @@
         params, event = command.execute(bug_params, dummy_event)
         self.assertEqual(bug_params, params)
         self.assertEqual(
-            InformationType.EMBARGOEDSECURITY, bug_params.information_type)
+            InformationType.PRIVATESECURITY, bug_params.information_type)
         self.assertEqual(dummy_event, event)
 
 
@@ -427,7 +427,7 @@
         params, event = command.execute(bug_params, dummy_event)
         self.assertEqual(bug_params, params)
         self.assertEqual(
-            InformationType.UNEMBARGOEDSECURITY, bug_params.information_type)
+            InformationType.PUBLICSECURITY, bug_params.information_type)
         self.assertTrue(IObjectModifiedEvent.providedBy(event))
 
     def test_execute_bug(self):
@@ -438,7 +438,7 @@
         exec_bug, event = command.execute(bug, None)
         self.assertEqual(bug, exec_bug)
         self.assertEqual(
-            InformationType.EMBARGOEDSECURITY, bug.information_type)
+            InformationType.PRIVATESECURITY, bug.information_type)
         self.assertTrue(IObjectModifiedEvent.providedBy(event))
 
     def test_execute_bug_params_with_rubbish(self):

=== modified file 'lib/lp/bugs/model/bugtask.py'
--- lib/lp/bugs/model/bugtask.py	2012-07-06 04:45:10 +0000
+++ lib/lp/bugs/model/bugtask.py	2012-07-17 06:39:20 +0000
@@ -1644,7 +1644,7 @@
             validate_new_target(bug, target)
             pillars.add(target.pillar)
             target_keys.append(bug_target_to_key(target))
-        if bug.information_type == InformationType.UNEMBARGOEDSECURITY:
+        if bug.information_type == InformationType.PUBLICSECURITY:
             for pillar in pillars:
                 if pillar.security_contact:
                     bug.subscribe(pillar.security_contact, owner)

=== modified file 'lib/lp/bugs/model/tests/test_bug.py'
--- lib/lp/bugs/model/tests/test_bugtask.py	2012-07-10 03:31:47 +0000
+++ lib/lp/bugs/model/tests/test_bugtask.py	2012-07-17 06:39:20 +0000
@@ -3379,7 +3379,7 @@
         # longer see the bug.
         def change_information_type(bug, owner):
             bug.transitionToInformationType(
-                InformationType.EMBARGOEDSECURITY, owner)
+                InformationType.PRIVATESECURITY, owner)
 
         self._assert_bug_change_unsubscribes(change_information_type, True)
 

=== modified file 'lib/lp/bugs/stories/bug-privacy/xx-bug-privacy.txt'
--- lib/lp/bugs/stories/bug-privacy/xx-bug-privacy.txt	2012-07-17 06:39:20 +0000
+++ lib/lp/bugs/stories/bug-privacy/xx-bug-privacy.txt	2012-07-17 06:39:20 +0000
@@ -37,7 +37,7 @@
     >>> browser.getControl(name="packagename_option").value = ["choose"]
     >>> browser.getControl(name="field.packagename").value = "evolution"
     >>> browser.getControl(name="field.comment").value = "secret info"
-    >>> browser.getControl("Embargoed Security").selected = True
+    >>> browser.getControl("Private Security").selected = True
     >>> browser.getControl("Submit Bug Report").click()
 
     >>> bug_id = browser.url.split("/")[-1]
@@ -88,7 +88,7 @@
     >>> browser.getControl(name="packagename_option").value = ["choose"]
     >>> browser.getControl(name="field.packagename").value = "evolution"
     >>> browser.getControl(name="field.comment").value = "secret info"
-    >>> browser.getControl("Embargoed Security").selected = True
+    >>> browser.getControl("Private Security").selected = True
     >>> browser.getControl("Submit Bug Report").click()
 
     >>> other_bug_id = browser.url.split("/")[-1]

=== modified file 'lib/lp/bugs/stories/bug-privacy/xx-presenting-private-bugs.txt'
--- lib/lp/bugs/stories/bug-privacy/xx-presenting-private-bugs.txt	2012-07-17 06:39:20 +0000
+++ lib/lp/bugs/stories/bug-privacy/xx-presenting-private-bugs.txt	2012-07-17 06:39:20 +0000
@@ -24,7 +24,7 @@
 
     >>> browser.open("http://launchpad.dev/bugs/14";)
     >>> print extract_text(find_tag_by_id(browser.contents, 'privacy'))
-    This report contains Embargoed Security information...
+    This report contains Private Security information...
 
 But newer bugs that are filed private at creation time (like security
 bugs or where the product requests that bugs are private by default)
@@ -36,13 +36,13 @@
     >>> browser.getControl('Continue').click()
 
     >>> browser.getControl("Further information").value = "foo"
-    >>> browser.getControl("Embargoed Security").selected = True
+    >>> browser.getControl("Private Security").selected = True
     >>> browser.getControl("Submit Bug Report").click()
 
     >>> print browser.url
     http://bugs.launchpad.dev/firefox/+bug/...
     >>> print extract_text(find_tag_by_id(browser.contents, 'privacy'))
-    This report contains Embargoed Security information...
+    This report contains Private Security information...
 
 XXX 20080708 mpt: Bug 246671 again.
 

=== modified file 'lib/lp/bugs/stories/bugs/xx-bug-activity.txt'
--- lib/lp/bugs/stories/bugs/xx-bug-activity.txt	2012-07-17 06:39:20 +0000
+++ lib/lp/bugs/stories/bugs/xx-bug-activity.txt	2012-07-17 06:39:20 +0000
@@ -122,7 +122,7 @@
 
     >>> admin_browser.open(
     ...     'http://bugs.launchpad.dev/redfish/+bug/15/+secrecy')
-    >>> admin_browser.getControl("Embargoed Security").selected = True
+    >>> admin_browser.getControl("Private Security").selected = True
     >>> admin_browser.getControl("Change").click()
 
     >>> admin_browser.open('http://launchpad.dev/bugs/15')
@@ -339,5 +339,5 @@
     Foo Bar (name16)
     ... ago
     information type:
-    Embargoed Security => Private User
+    Private Security => Private User
     --------

=== modified file 'lib/lp/bugs/stories/initial-bug-contacts/xx-initial-bug-contacts.txt'
--- lib/lp/bugs/stories/initial-bug-contacts/xx-initial-bug-contacts.txt	2012-06-22 05:52:17 +0000
+++ lib/lp/bugs/stories/initial-bug-contacts/xx-initial-bug-contacts.txt	2012-07-17 06:39:20 +0000
@@ -149,7 +149,7 @@
     >>> browser.getControl('Continue').click()
 
     >>> browser.getControl(name="field.comment").value = "a PRIVATE bug"
-    >>> browser.getControl("Embargoed Security").selected = True
+    >>> browser.getControl("Private Security").selected = True
     >>> browser.getControl("Submit Bug Report").click()
 
     >>> other_bug_id = browser.url.split("/")[-1]
@@ -222,7 +222,7 @@
     >>> browser.getControl('Continue').click()
 
     >>> browser.getControl(name="field.comment").value = "top sekrit"
-    >>> browser.getControl("Embargoed Security").selected = True
+    >>> browser.getControl("Private Security").selected = True
     >>> browser.getControl("Submit Bug Report").click()
 
     >>> other_bug_id = browser.url.split("/")[-1]

=== modified file 'lib/lp/bugs/stories/upstream-bugprivacy/xx-upstream-bug-privacy.txt'
--- lib/lp/bugs/stories/upstream-bugprivacy/xx-upstream-bug-privacy.txt	2012-06-22 05:52:17 +0000
+++ lib/lp/bugs/stories/upstream-bugprivacy/xx-upstream-bug-privacy.txt	2012-07-17 06:39:20 +0000
@@ -11,7 +11,7 @@
     ...     "this is a newly created private bug")
     >>> browser.getControl(name="field.comment").value = (
     ...     "very secret info here")
-    >>> browser.getControl("Embargoed Security").selected = True
+    >>> browser.getControl("Private Security").selected = True
     >>> browser.getControl("Submit Bug Report").click()
 
     >>> bug_id = browser.url.split("/")[-1]
@@ -73,7 +73,7 @@
 
     >>> browser.getControl(name="field.comment").value = (
     ...     "very secret info here")
-    >>> browser.getControl("Embargoed Security").selected = True
+    >>> browser.getControl("Private Security").selected = True
     >>> browser.getControl("Submit Bug Report").click()
 
     >>> other_bug_id = browser.url.split("/")[-1]
@@ -223,19 +223,19 @@
   ... Content-Length: 429
   ... Content-Type: multipart/form-data; boundary=---------------------------10389799518848978361196772104
   ... 
-  ... -----------------------------10389799518848978361196772104
-  ... Content-Disposition: form-data; name="field.private.used"
-  ... 
-  ... 
-  ... -----------------------------10389799518848978361196772104
-  ... Content-Disposition: form-data; name="field.private"
-  ... 
-  ... on
-  ... -----------------------------10389799518848978361196772104
-  ... Content-Disposition: form-data; name="UPDATE_SUBMIT"
-  ... 
-  ... Change
-  ... -----------------------------10389799518848978361196772104--
+  ... -----------------------------10389799518848978361196772104
+  ... Content-Disposition: form-data; name="field.private.used"
+  ... 
+  ... 
+  ... -----------------------------10389799518848978361196772104
+  ... Content-Disposition: form-data; name="field.private"
+  ... 
+  ... on
+  ... -----------------------------10389799518848978361196772104
+  ... Content-Disposition: form-data; name="UPDATE_SUBMIT"
+  ... 
+  ... Change
+  ... -----------------------------10389799518848978361196772104--
   ... """)
   HTTP/1.1 200 Ok
   ...

=== modified file 'lib/lp/bugs/tests/test_bugchanges.py'
--- lib/lp/bugs/tests/test_bugchanges.py	2012-07-17 06:39:20 +0000
+++ lib/lp/bugs/tests/test_bugchanges.py	2012-07-17 06:39:20 +0000
@@ -630,7 +630,7 @@
         bug_before_modification = Snapshot(bug, providing=providedBy(bug))
         with FeatureFixture(feature_flag):
             bug.transitionToInformationType(
-                InformationType.EMBARGOEDSECURITY, self.user)
+                InformationType.PRIVATESECURITY, self.user)
             notify(ObjectModifiedEvent(
                 bug, bug_before_modification, ['information_type'],
                 user=self.user))
@@ -639,7 +639,7 @@
             'person': self.user,
             'whatchanged': 'information type',
             'oldvalue': 'Public',
-            'newvalue': 'Embargoed Security',
+            'newvalue': 'Private Security',
             }
         information_type_change_notification = {
             'text': '** Information type changed from Public to Embargoed '
@@ -663,13 +663,13 @@
         lp_bug = webservice.load(api_url(bug))
         with FeatureFixture(feature_flag):
             lp_bug.transitionToInformationType(
-                information_type='Embargoed Security')
+                information_type='Private Security')
 
         information_type_change_activity = {
             'person': person,
             'whatchanged': 'information type',
             'oldvalue': 'Public',
-            'newvalue': 'Embargoed Security',
+            'newvalue': 'Private Security',
             }
         information_type_change_notification = {
             'text': '** Information type changed from Public to Embargoed '

=== modified file 'lib/lp/bugs/tests/test_bugtask_search.py'
--- lib/lp/bugs/tests/test_bugtask_search.py	2012-07-16 01:24:26 +0000
+++ lib/lp/bugs/tests/test_bugtask_search.py	2012-07-17 06:39:20 +0000
@@ -414,14 +414,14 @@
         # Search results can be filtered by information_type.
         with person_logged_in(self.owner):
             self.bugtasks[2].bug.transitionToInformationType(
-                InformationType.EMBARGOEDSECURITY, self.owner)
+                InformationType.PRIVATESECURITY, self.owner)
         params = self.getBugTaskSearchParams(
             user=self.owner,
-            information_type=InformationType.EMBARGOEDSECURITY)
+            information_type=InformationType.PRIVATESECURITY)
         self.assertSearchFinds(params, [self.bugtasks[2]])
         params = self.getBugTaskSearchParams(
             user=self.owner,
-            information_type=InformationType.UNEMBARGOEDSECURITY)
+            information_type=InformationType.PUBLICSECURITY)
         self.assertSearchFinds(params, [])
 
     def test_omit_duplicate_bugs(self):

=== modified file 'lib/lp/bugs/tests/test_bugtaskflat_triggers.py'
--- lib/lp/bugs/tests/test_bugtaskflat_triggers.py	2012-05-07 07:43:07 +0000
+++ lib/lp/bugs/tests/test_bugtaskflat_triggers.py	2012-07-17 06:39:20 +0000
@@ -309,7 +309,7 @@
         task = self.makeLoggedInTask()
         with self.bugtaskflat_is_updated(task, ['information_type']):
             removeSecurityProxy(task.bug).information_type = (
-                InformationType.UNEMBARGOEDSECURITY)
+                InformationType.PUBLICSECURITY)
 
     def test_bug_make_private(self):
         # Triggers maintain BugTaskFlat when a bug is made private.

=== modified file 'lib/lp/bugs/tests/test_searchtasks_webservice.py'
--- lib/lp/bugs/tests/test_searchtasks_webservice.py	2012-07-17 06:39:20 +0000
+++ lib/lp/bugs/tests/test_searchtasks_webservice.py	2012-07-17 06:39:20 +0000
@@ -96,7 +96,7 @@
             self.product = self.factory.makeProduct()
         self.bug = self.factory.makeBug(
             product=self.product,
-            information_type=InformationType.EMBARGOEDSECURITY)
+            information_type=InformationType.PRIVATESECURITY)
         self.webservice = LaunchpadWebServiceCaller(
             'launchpad-library', 'salgado-change-anything')
 
@@ -108,7 +108,7 @@
     def test_search_returns_results(self):
         # A matching search returns results.
         response = self.search(
-            "devel", information_type="Embargoed Security")
+            "devel", information_type="Private Security")
         self.assertEqual(response['total_size'], 1)
 
     def test_search_returns_no_results(self):

=== modified file 'lib/lp/bugs/xmlrpc/bug.py'
--- lib/lp/bugs/xmlrpc/bug.py	2012-03-23 06:10:28 +0000
+++ lib/lp/bugs/xmlrpc/bug.py	2012-07-17 06:39:20 +0000
@@ -105,7 +105,7 @@
                     subscriber_list.append(subscriber)
 
         if security_related:
-            information_type = InformationType.EMBARGOEDSECURITY
+            information_type = InformationType.PRIVATESECURITY
         else:
             information_type = InformationType.PUBLIC
 

=== modified file 'lib/lp/code/browser/branch.py'
--- lib/lp/code/browser/branch.py	2012-07-17 06:39:20 +0000
+++ lib/lp/code/browser/branch.py	2012-07-17 06:39:20 +0000
@@ -1088,13 +1088,13 @@
                 InformationType.PROPRIETARY,
                 )
 
-            # We only show Embargoed Security and Unembargoed Security
+            # We only show Private Security and Public Security
             # if the branch is linked to a bug with one of those types,
             # as they're confusing and not generally useful otherwise.
             # Once Proprietary is fully deployed, it should be added here.
             hidden_types = (
-                InformationType.UNEMBARGOEDSECURITY,
-                InformationType.EMBARGOEDSECURITY,
+                InformationType.PUBLICSECURITY,
+                InformationType.PRIVATESECURITY,
                 )
             if set(allowed_types).intersection(hidden_types):
                 params = BugTaskSearchParams(

=== modified file 'lib/lp/code/browser/tests/test_branch.py'
--- lib/lp/code/browser/tests/test_branch.py	2012-07-17 06:39:20 +0000
+++ lib/lp/code/browser/tests/test_branch.py	2012-07-17 06:39:20 +0000
@@ -949,7 +949,7 @@
 
     def test_public_branch(self):
         # A normal public branch on a public project can only be public.
-        # We don't show information types like Unembargoed Security
+        # We don't show information types like Public Security
         # unless there's a linked branch of that type, as they're not
         # useful or unconfusing otherwise.
         # The model doesn't enforce this, so it's just a UI thing.
@@ -958,18 +958,18 @@
         self.assertShownTypes([InformationType.PUBLIC], branch)
 
     def test_public_branch_with_security_bug(self):
-        # A public branch can be set to Unembargoed Security if it has a
-        # linked Unembargoed Security bug. The project policy doesn't
-        # allow private branches, so Embargoed Security and Private
+        # A public branch can be set to Public Security if it has a
+        # linked Public Security bug. The project policy doesn't
+        # allow private branches, so Private Security and Private
         # are unavailable.
         branch = self.factory.makeBranch(
             information_type=InformationType.PUBLIC)
         bug = self.factory.makeBug(
-            information_type=InformationType.UNEMBARGOEDSECURITY)
+            information_type=InformationType.PUBLICSECURITY)
         with admin_logged_in():
             branch.linkBug(bug, branch.owner)
         self.assertShownTypes(
-            [InformationType.PUBLIC, InformationType.UNEMBARGOEDSECURITY],
+            [InformationType.PUBLIC, InformationType.PUBLICSECURITY],
             branch)
 
     def test_branch_with_disallowed_type(self):
@@ -990,12 +990,12 @@
         branch = self.factory.makeBranch(
             product=product, stacked_on=stacked_on_branch,
             owner=product.owner,
-            information_type=InformationType.EMBARGOEDSECURITY)
+            information_type=InformationType.PRIVATESECURITY)
         with admin_logged_in():
             branch.product.setBranchVisibilityTeamPolicy(
                 branch.owner, BranchVisibilityRule.PRIVATE)
         self.assertShownTypes(
-            [InformationType.EMBARGOEDSECURITY, InformationType.USERDATA],
+            [InformationType.PRIVATESECURITY, InformationType.USERDATA],
             branch)
 
     def test_private_branch(self):
@@ -1011,7 +1011,7 @@
 
     def test_private_branch_with_security_bug(self):
         # Branches on projects that allow private branches can use the
-        # Embargoed Security information type if they have a security
+        # Private Security information type if they have a security
         # bug linked.
         branch = self.factory.makeBranch(
             information_type=InformationType.PUBLIC)
@@ -1019,12 +1019,12 @@
             branch.product.setBranchVisibilityTeamPolicy(
                 branch.owner, BranchVisibilityRule.PRIVATE)
         bug = self.factory.makeBug(
-            information_type=InformationType.UNEMBARGOEDSECURITY)
+            information_type=InformationType.PUBLICSECURITY)
         with admin_logged_in():
             branch.linkBug(bug, branch.owner)
         self.assertShownTypes(
-            [InformationType.PUBLIC, InformationType.UNEMBARGOEDSECURITY,
-             InformationType.EMBARGOEDSECURITY, InformationType.USERDATA,
+            [InformationType.PUBLIC, InformationType.PUBLICSECURITY,
+             InformationType.PRIVATESECURITY, InformationType.USERDATA,
              InformationType.PROPRIETARY],
             branch)
 

=== modified file 'lib/lp/code/model/tests/test_branch.py'
--- lib/lp/code/model/tests/test_branch.py	2012-07-16 02:57:19 +0000
+++ lib/lp/code/model/tests/test_branch.py	2012-07-17 06:39:20 +0000
@@ -2526,9 +2526,9 @@
         branch = self.factory.makeBranch(
             stacked_on=stacked_on, information_type=InformationType.USERDATA)
         branch.transitionToInformationType(
-            InformationType.UNEMBARGOEDSECURITY, branch.owner)
+            InformationType.PUBLICSECURITY, branch.owner)
         self.assertEqual(
-            InformationType.UNEMBARGOEDSECURITY, branch.information_type)
+            InformationType.PUBLICSECURITY, branch.information_type)
 
     def test_transition_reconciles_access(self):
         # transitionToStatus calls _reconcileAccess to make the sharing
@@ -2537,10 +2537,10 @@
             information_type=InformationType.USERDATA)
         with admin_logged_in():
             branch.transitionToInformationType(
-                InformationType.EMBARGOEDSECURITY, branch.owner,
+                InformationType.PRIVATESECURITY, branch.owner,
                 verify_policy=False)
         self.assertEqual(
-            InformationType.EMBARGOEDSECURITY,
+            InformationType.PRIVATESECURITY,
             get_policies_for_artifact(branch)[0].type)
 
     def test_can_transition_with_no_subscribers(self):

=== modified file 'lib/lp/registry/enums.py'
--- lib/lp/registry/enums.py	2012-07-17 06:39:20 +0000
+++ lib/lp/registry/enums.py	2012-07-17 06:39:20 +0000
@@ -37,14 +37,14 @@
         Everyone can see this information.
         """)
 
-    UNEMBARGOEDSECURITY = DBItem(2, """
-        Unembargoed Security
+    PUBLICSECURITY = DBItem(2, """
+        Public Security
 
         Everyone can see this security related information.
         """)
 
-    EMBARGOEDSECURITY = DBItem(3, """
-        Embargoed Security
+    PRIVATESECURITY = DBItem(3, """
+        Private Security
 
        Only the security group can see this information.
         """)
@@ -63,16 +63,16 @@
 
 
 PUBLIC_INFORMATION_TYPES = (
-    InformationType.PUBLIC, InformationType.UNEMBARGOEDSECURITY)
+    InformationType.PUBLIC, InformationType.PUBLICSECURITY)
 
 
 PRIVATE_INFORMATION_TYPES = (
-    InformationType.EMBARGOEDSECURITY, InformationType.USERDATA,
+    InformationType.PRIVATESECURITY, InformationType.USERDATA,
     InformationType.PROPRIETARY)
 
 
 SECURITY_INFORMATION_TYPES = (
-    InformationType.UNEMBARGOEDSECURITY, InformationType.EMBARGOEDSECURITY)
+    InformationType.PUBLICSECURITY, InformationType.PRIVATESECURITY)
 
 
 class SharingPermission(DBEnumeratedType):

=== modified file 'lib/lp/registry/help/sharing.html'
--- lib/lp/registry/help/sharing.html	2012-03-21 01:06:04 +0000
+++ lib/lp/registry/help/sharing.html	2012-07-17 06:39:20 +0000
@@ -43,7 +43,7 @@
             to people affiliated with the project and its organisation.
         </dd>
 
-        <dt>Embargoed Security</dt>
+        <dt>Private Security</dt>
         <dd>
             Visible if you're involved in fixing and deploying critical
             vulnerability and exploits

=== modified file 'lib/lp/registry/javascript/sharing/tests/test_sharingdetails.js'
--- lib/lp/registry/javascript/sharing/tests/test_sharingdetails.js	2012-07-17 06:39:20 +0000
+++ lib/lp/registry/javascript/sharing/tests/test_sharingdetails.js	2012-07-17 06:39:20 +0000
@@ -23,7 +23,7 @@
                             bug_id: '2',
                             bug_importance: 'critical',
                             bug_summary:'Everything is broken.',
-                            information_type: 'Embargoed Security'
+                            information_type: 'Private Security'
                         }
                     ],
                     branches: [

=== modified file 'lib/lp/registry/model/distribution.py'
--- lib/lp/registry/model/distribution.py	2012-07-09 23:10:36 +0000
+++ lib/lp/registry/model/distribution.py	2012-07-17 06:39:20 +0000
@@ -1754,7 +1754,7 @@
             owner=owner, purpose=ArchivePurpose.PRIMARY)
         policies = itertools.product(
             (distro,), (InformationType.USERDATA,
-                InformationType.EMBARGOEDSECURITY))
+                InformationType.PRIVATESECURITY))
         getUtility(IAccessPolicySource).create(policies)
         return distro
 

=== modified file 'lib/lp/registry/model/product.py'
--- lib/lp/registry/model/product.py	2012-07-13 08:29:56 +0000
+++ lib/lp/registry/model/product.py	2012-07-17 06:39:20 +0000
@@ -1546,7 +1546,7 @@
 
         # Add default AccessPolicies.
         product._ensurePolicies((InformationType.USERDATA,
-                InformationType.EMBARGOEDSECURITY))
+                InformationType.PRIVATESECURITY))
         return product
 
     def forReview(self, search_text=None, active=None,

=== modified file 'lib/lp/registry/services/sharingservice.py'
--- lib/lp/registry/services/sharingservice.py	2012-07-16 10:25:45 +0000
+++ lib/lp/registry/services/sharingservice.py	2012-07-17 06:39:20 +0000
@@ -202,7 +202,7 @@
     def getInformationTypes(self, pillar):
         """See `ISharingService`."""
         allowed_types = [
-            InformationType.EMBARGOEDSECURITY,
+            InformationType.PRIVATESECURITY,
             InformationType.USERDATA]
         # Products with current commercial subscriptions are also allowed to
         # have a PROPRIETARY information type.

=== modified file 'lib/lp/registry/services/tests/test_sharingservice.py'
--- lib/lp/registry/services/tests/test_sharingservice.py	2012-07-16 10:25:45 +0000
+++ lib/lp/registry/services/tests/test_sharingservice.py	2012-07-17 06:39:20 +0000
@@ -129,21 +129,21 @@
         product = self.factory.makeProduct()
         self._assert_getInformationTypes(
             product,
-            [InformationType.EMBARGOEDSECURITY, InformationType.USERDATA])
+            [InformationType.PRIVATESECURITY, InformationType.USERDATA])
 
     def test_getInformationTypes_expired_commercial_product(self):
         product = self.factory.makeProduct()
         self.factory.makeCommercialSubscription(product, expired=True)
         self._assert_getInformationTypes(
             product,
-            [InformationType.EMBARGOEDSECURITY, InformationType.USERDATA])
+            [InformationType.PRIVATESECURITY, InformationType.USERDATA])
 
     def test_getInformationTypes_commercial_product(self):
         product = self.factory.makeProduct()
         self.factory.makeCommercialSubscription(product)
         self._assert_getInformationTypes(
             product,
-            [InformationType.EMBARGOEDSECURITY,
+            [InformationType.PRIVATESECURITY,
              InformationType.USERDATA,
              InformationType.PROPRIETARY])
 
@@ -151,7 +151,7 @@
         distro = self.factory.makeDistribution()
         self._assert_getInformationTypes(
             distro,
-            [InformationType.EMBARGOEDSECURITY, InformationType.USERDATA])
+            [InformationType.PRIVATESECURITY, InformationType.USERDATA])
 
     def test_jsonShareeData_with_Some(self):
         # jsonShareeData returns the expected data for a grantee with
@@ -252,7 +252,7 @@
             owner_data = self._makeShareeData(
                 pillar.owner,
                 [(InformationType.USERDATA, SharingPermission.ALL),
-                 (InformationType.EMBARGOEDSECURITY, SharingPermission.ALL)],
+                 (InformationType.PRIVATESECURITY, SharingPermission.ALL)],
                 [])
             expected_sharees.append(owner_data)
         self.assertContentEqual(expected_sharees, sharees)
@@ -431,7 +431,7 @@
         # cases correctly.
         # First, a grant that is in the add set - it wil be retained.
         es_policy = getUtility(IAccessPolicySource).find(((
-            pillar, InformationType.EMBARGOEDSECURITY),))[0]
+            pillar, InformationType.PRIVATESECURITY),))[0]
         ud_policy = getUtility(IAccessPolicySource).find(((
             pillar, InformationType.USERDATA),))[0]
         self.factory.makeAccessPolicyGrant(
@@ -463,7 +463,7 @@
 
         # Now call sharePillarInformation will the grants we want.
         permissions = {
-            InformationType.EMBARGOEDSECURITY: SharingPermission.ALL,
+            InformationType.PRIVATESECURITY: SharingPermission.ALL,
             InformationType.USERDATA: SharingPermission.SOME,
             InformationType.PROPRIETARY: SharingPermission.NOTHING}
         with FeatureFixture(WRITE_FLAG):
@@ -479,11 +479,11 @@
         self.assertEqual(grantor, grant.grantor)
         self.assertEqual(sharee, grant.grantee)
         expected_permissions = [
-            (InformationType.EMBARGOEDSECURITY, SharingPermission.ALL),
+            (InformationType.PRIVATESECURITY, SharingPermission.ALL),
             (InformationType.USERDATA, SharingPermission.SOME)]
         expected_sharee_data = self._makeShareeData(
             sharee, expected_permissions,
-            [InformationType.EMBARGOEDSECURITY, InformationType.USERDATA])
+            [InformationType.PRIVATESECURITY, InformationType.USERDATA])
         self.assertContentEqual(expected_sharee_data, sharee_data)
         # Check that getPillarSharees returns what we expect.
         if pillar_type == 'product':
@@ -492,7 +492,7 @@
                  {ud_policy: SharingPermission.SOME,
                   es_policy: SharingPermission.ALL},
                  [InformationType.USERDATA,
-                  InformationType.EMBARGOEDSECURITY]),
+                  InformationType.PRIVATESECURITY]),
                  ]
         else:
             expected_sharee_grants = [
@@ -500,7 +500,7 @@
                  {es_policy: SharingPermission.ALL,
                   ud_policy: SharingPermission.SOME},
                  [InformationType.USERDATA,
-                  InformationType.EMBARGOEDSECURITY]),
+                  InformationType.PRIVATESECURITY]),
                  ]
 
         sharee_grants = list(self.service.getPillarSharees(pillar))
@@ -631,7 +631,7 @@
             policy, SharingPermission.SOME) for policy in access_policies])
         yet_another_person_data = (
             yet_another, policy_permissions,
-            [InformationType.EMBARGOEDSECURITY, InformationType.USERDATA])
+            [InformationType.PRIVATESECURITY, InformationType.USERDATA])
         expected_data.append(yet_another_person_data)
         if pillar_type == 'product':
             policy_permissions = dict([(
@@ -1240,7 +1240,7 @@
         # getVisibleArtifacts excludes bugs after change of information type.
         def change_info_type(bug, owner):
             bug.transitionToInformationType(
-                InformationType.EMBARGOEDSECURITY, owner)
+                InformationType.PRIVATESECURITY, owner)
 
         self._assert_getVisibleArtifacts_bug_change(change_info_type)
 
@@ -1268,7 +1268,7 @@
                     {InformationType.USERDATA: SharingPermission.ALL})
                 self.service.sharePillarInformation(
                     product, wrong_person, product.owner,
-                    {InformationType.EMBARGOEDSECURITY: SharingPermission.ALL})
+                    {InformationType.PRIVATESECURITY: SharingPermission.ALL})
         self.assertEqual(
             False,
             self.service.checkPillarAccess(

=== modified file 'lib/lp/registry/tests/test_accesspolicy.py'
--- lib/lp/registry/tests/test_accesspolicy.py	2012-06-18 03:18:36 +0000
+++ lib/lp/registry/tests/test_accesspolicy.py	2012-07-17 06:39:20 +0000
@@ -59,7 +59,7 @@
         wanted = [
             (self.factory.makeProduct(), InformationType.PROPRIETARY),
             (self.factory.makeDistribution(),
-                InformationType.UNEMBARGOEDSECURITY),
+                InformationType.PUBLICSECURITY),
             ]
         policies = getUtility(IAccessPolicySource).create(wanted)
         self.assertThat(
@@ -77,17 +77,17 @@
 
         wanted = [
             (product, InformationType.PROPRIETARY),
-            (product, InformationType.UNEMBARGOEDSECURITY),
+            (product, InformationType.PUBLICSECURITY),
             (distribution, InformationType.PROPRIETARY),
-            (distribution, InformationType.UNEMBARGOEDSECURITY),
+            (distribution, InformationType.PUBLICSECURITY),
             (other_product, InformationType.PROPRIETARY),
             ]
         getUtility(IAccessPolicySource).create(wanted)
 
         query = [
             (product, InformationType.PROPRIETARY),
-            (product, InformationType.UNEMBARGOEDSECURITY),
-            (distribution, InformationType.UNEMBARGOEDSECURITY),
+            (product, InformationType.PUBLICSECURITY),
+            (distribution, InformationType.PUBLICSECURITY),
             ]
         self.assertContentEqual(
             query,
@@ -115,11 +115,11 @@
         distribution = self.factory.makeProduct()
         other_product = self.factory.makeProduct()
         policies = (
-            (product, InformationType.EMBARGOEDSECURITY),
+            (product, InformationType.PRIVATESECURITY),
             (product, InformationType.USERDATA),
-            (distribution, InformationType.EMBARGOEDSECURITY),
+            (distribution, InformationType.PRIVATESECURITY),
             (distribution, InformationType.USERDATA),
-            (other_product, InformationType.EMBARGOEDSECURITY),
+            (other_product, InformationType.PRIVATESECURITY),
             (other_product, InformationType.USERDATA),
             )
         self.assertContentEqual(

=== modified file 'lib/lp/registry/tests/test_distribution.py'
--- lib/lp/registry/tests/test_distribution.py	2012-07-09 08:24:18 +0000
+++ lib/lp/registry/tests/test_distribution.py	2012-07-17 06:39:20 +0000
@@ -273,7 +273,7 @@
         distro = self.factory.makeDistribution()
         ap = getUtility(IAccessPolicySource).findByPillar((distro,))
         expected = [
-            InformationType.USERDATA, InformationType.EMBARGOEDSECURITY]
+            InformationType.USERDATA, InformationType.PRIVATESECURITY]
         self.assertContentEqual(expected, [policy.type for policy in ap])
 
 

=== modified file 'lib/lp/registry/tests/test_product.py'
--- lib/lp/registry/tests/test_product.py	2012-07-09 02:00:55 +0000
+++ lib/lp/registry/tests/test_product.py	2012-07-17 06:39:20 +0000
@@ -358,7 +358,7 @@
         product = self.factory.makeProduct()
         ap = getUtility(IAccessPolicySource).findByPillar((product,))
         expected = [
-            InformationType.USERDATA, InformationType.EMBARGOEDSECURITY]
+            InformationType.USERDATA, InformationType.PRIVATESECURITY]
         self.assertContentEqual(expected, [policy.type for policy in ap])
 
     def test_product_creation_grants_maintainer_access(self):
@@ -383,7 +383,7 @@
 
         ap = getUtility(IAccessPolicySource).findByPillar((product,))
         expected = [
-            InformationType.USERDATA, InformationType.EMBARGOEDSECURITY,
+            InformationType.USERDATA, InformationType.PRIVATESECURITY,
             InformationType.PROPRIETARY]
         self.assertContentEqual(expected, [policy.type for policy in ap])
 

=== modified file 'lib/lp/registry/tests/test_sharingjob.py'
--- lib/lp/registry/tests/test_sharingjob.py	2012-07-13 10:21:38 +0000
+++ lib/lp/registry/tests/test_sharingjob.py	2012-07-17 06:39:20 +0000
@@ -210,7 +210,7 @@
                 owner, [bug])
             with person_logged_in(owner):
                 bug.transitionToInformationType(
-                            InformationType.EMBARGOEDSECURITY, owner)
+                            InformationType.PRIVATESECURITY, owner)
             return job, IRemoveArtifactSubscriptionsJobSource.getName()
 
         self._assert_run_cronscript(create_job)
@@ -397,7 +397,7 @@
     def test_change_information_type_branch(self):
         def change_information_type(branch):
             removeSecurityProxy(branch).information_type = (
-                InformationType.EMBARGOEDSECURITY)
+                InformationType.PRIVATESECURITY)
 
         self._assert_branch_change_unsubscribes(change_information_type)
 
@@ -408,7 +408,7 @@
             # Set the info_type attribute directly since
             # transitionToInformationType queues a job.
             removeSecurityProxy(bug).information_type = (
-                InformationType.EMBARGOEDSECURITY)
+                InformationType.PRIVATESECURITY)
 
         self._assert_bug_change_unsubscribes(change_information_type)
 
@@ -454,7 +454,7 @@
 
         bug2, ignored = self._make_subscribed_bug(
             person_grantee, product=pillar,
-            information_type=InformationType.EMBARGOEDSECURITY)
+            information_type=InformationType.PRIVATESECURITY)
 
         # Now run the job, removing access to userdata artifacts.
         getUtility(IRemoveArtifactSubscriptionsJobSource).create(

=== modified file 'lib/lp/registry/tests/test_teammembership.py'
--- lib/lp/registry/tests/test_teammembership.py	2012-06-29 02:15:05 +0000
+++ lib/lp/registry/tests/test_teammembership.py	2012-07-17 06:39:20 +0000
@@ -1029,7 +1029,7 @@
             members=[person_grantee])
         bug2, bug2_owner = self._make_subscribed_bug(
             team_grantee, product=product,
-            information_type=InformationType.EMBARGOEDSECURITY)
+            information_type=InformationType.PRIVATESECURITY)
         # Add a subscription for the person_grantee.
         with person_logged_in(bug2_owner):
             bug2.subscribe(person_grantee, bug2_owner)

=== modified file 'lib/lp/registry/vocabularies.py'
--- lib/lp/registry/vocabularies.py	2012-07-17 06:39:20 +0000
+++ lib/lp/registry/vocabularies.py	2012-07-17 06:39:20 +0000
@@ -2248,7 +2248,7 @@
         types = []
         if not public_only:
             types = [
-                InformationType.EMBARGOEDSECURITY,
+                InformationType.PRIVATESECURITY,
                 InformationType.USERDATA]
             # So long as not disabled by the feature flag, Proprietary is
             # allowed for:
@@ -2283,7 +2283,7 @@
             not IProduct.providedBy(context) or
             not context.private_bugs)):
             types = [InformationType.PUBLIC,
-                     InformationType.UNEMBARGOEDSECURITY] + types
+                     InformationType.PUBLICSECURITY] + types
 
         terms = []
         for type in types:


Follow ups
--- lib/lp/bugs/browser/tests/test_bugtarget_filebug.py	2012-07-17 06:39:20 +0000
+++ lib/lp/bugs/browser/tests/test_bugtarget_filebug.py	2012-07-17 06:39:20 +0000
@@ -383,9 +383,9 @@
 
     def test_filebug_set_information_type(self):
         # When we specify the bug's information_type, it is set.
-        bug = self.filebug_via_view(information_type='EMBARGOEDSECURITY')
+        bug = self.filebug_via_view(information_type='PRIVATESECURITY')
         self.assertEqual(
-            InformationType.EMBARGOEDSECURITY, bug.information_type)
+            InformationType.PRIVATESECURITY, bug.information_type)
 
     def test_filebug_information_type_with_private_bugs(self):
         # If we don't specify the bug's information_type, it is USERDATA for
@@ -486,18 +486,18 @@
         self.assertEqual(InformationType.PUBLIC, bug.information_type)
 
     def test_filebug_security_related(self):
         # Security related bugs are EMBARGOEDSECURITY for products with
         # private_bugs=False.
         bug = self.filebug_via_view(security_related=True)
         self.assertEqual(
-            InformationType.EMBARGOEDSECURITY, bug.information_type)
+            InformationType.PRIVATESECURITY, bug.information_type)
 
     def test_filebug_security_related_with_private_bugs(self):
         # Security related bugs are EMBARGOEDSECURITY for products with
         # private_bugs=True.
         bug = self.filebug_via_view(private_bugs=True, security_related=True)
         self.assertEqual(
-            InformationType.EMBARGOEDSECURITY, bug.information_type)
+            InformationType.PRIVATESECURITY, bug.information_type)
 
     def test_filebug_with_private_bugs(self):
         # Non security related bugs are USERDATA for products with
@@ -486,18 +486,18 @@
 
     def test_filebug_security_related(self):
-        # Security related bugs are EMBARGOEDSECURITY for products with
+        # Security related bugs are PRIVATESECURITY for products with
         # private_bugs=False.
         bug = self.filebug_via_view(security_related=True)
@@ -486,18 +486,18 @@
 
     def test_filebug_security_related_with_private_bugs(self):
-        # Security related bugs are EMBARGOEDSECURITY for products with
+        # Security related bugs are PRIVATESECURITY for products with
         # private_bugs=True.
         bug = self.filebug_via_view(private_bugs=True, security_related=True)

=== modified file 'lib/lp/bugs/browser/tests/test_bugtask.py'
--- lib/lp/bugs/model/tests/test_bug.py	2012-07-10 03:31:47 +0000
+++ lib/lp/bugs/model/tests/test_bug.py	2012-07-17 06:39:20 +0000
@@ -613,7 +613,7 @@
         bug = self.factory.makeBug(owner=bug_owner, product=bug_product)
         with person_logged_in(bug_owner):
             if private_security_related:
-                information_type = InformationType.EMBARGOEDSECURITY
+                information_type = InformationType.PRIVATESECURITY
             else:
                 information_type = InformationType.PUBLIC
             bug.transitionToInformationType(information_type, bug_owner)
@@ -631,8 +631,8 @@
         return (bug, bug_owner, naked_bugtask_a, naked_bugtask_b,
                 naked_default_bugtask)
 
-    def test_transition_to_EMBARGOEDSECURITY_information_type(self):
-        # When a bug is marked as EMBARGOEDSECURITY, the direct subscribers
+    def test_transition_to_PRIVATESECURITY_information_type(self):
+        # When a bug is marked as PRIVATESECURITY, the direct subscribers
         # should include:
         # - the bug reporter
         # - the bugtask pillar security contacts (if set)
@@ -652,7 +652,7 @@
                 bug.subscribe(subscriber, bug_owner)
             who = self.factory.makePerson(name='who')
             bug.transitionToInformationType(
-                InformationType.EMBARGOEDSECURITY, who=who)
+                InformationType.PRIVATESECURITY, who=who)
             subscribers = bug.getDirectSubscribers()
             initial_subscribers.update(bug.getDirectSubscribers())
         expected_subscribers = set((
@@ -690,7 +690,7 @@
         expected_subscribers.update(initial_subscribers)
         self.assertContentEqual(expected_subscribers, subscribers)
 
-    def test_transition_to_UNEMBARGOEDSECURITY_information_type(self):
+    def test_transition_to_PUBLICSECURITY_information_type(self):
         # When a security bug is unembargoed, direct subscribers should
         # include:
         # - the bug reporter
@@ -709,7 +709,7 @@
                 bug.subscribe(subscriber, bug_owner)
             who = self.factory.makePerson(name='who')
             bug.transitionToInformationType(
-                InformationType.UNEMBARGOEDSECURITY, who)
+                InformationType.PUBLICSECURITY, who)
             subscribers = bug.getDirectSubscribers()
         expected_subscribers = set((
             default_bugtask.pillar.driver,
@@ -773,14 +773,14 @@
 
     def test_setPillarOwnerSubscribedIfNoSecurityContact(self):
         # The pillar owner is subscribed if the security contact is not set
         # and the bug is marked as EMBARGOEDSECURITY.
 
         bug_owner = self.factory.makePerson(name='bugowner')
         bug = self.factory.makeBug(owner=bug_owner)
         with person_logged_in(bug_owner):
             who = self.factory.makePerson(name='who')
             bug.transitionToInformationType(
-                InformationType.EMBARGOEDSECURITY, who)
+                InformationType.PRIVATESECURITY, who)
             subscribers = bug.getDirectSubscribers()
         naked_bugtask = removeSecurityProxy(bug).default_bugtask
         self.assertContentEqual(
@@ -829,11 +829,11 @@
         private_bug = self.factory.makeBug(
             information_type=InformationType.USERDATA)
         private_sec_bug = self.factory.makeBug(
-            information_type=InformationType.EMBARGOEDSECURITY)
+            information_type=InformationType.PRIVATESECURITY)
         mapping = (
             (bug, InformationType.PUBLIC),
             (private_bug, InformationType.USERDATA),
-            (private_sec_bug, InformationType.EMBARGOEDSECURITY),
+            (private_sec_bug, InformationType.PRIVATESECURITY),
             )
         [self.assertEqual(m[1], m[0].information_type) for m in mapping]
 
@@ -841,7 +841,7 @@
         # transitionToTarget updates the AccessPolicyArtifacts related
         # to the bug.
         bug = self.factory.makeBug(
-            information_type=InformationType.EMBARGOEDSECURITY)
+            information_type=InformationType.PRIVATESECURITY)
 
         with admin_logged_in():
             product = bug.default_bugtask.product
@@ -867,18 +867,18 @@
         # correct information type.
         owner = self.factory.makePerson()
         bug = self.factory.makeBug(
-            information_type=InformationType.EMBARGOEDSECURITY, owner=owner)
+            information_type=InformationType.PRIVATESECURITY, owner=owner)
         with person_logged_in(owner):
             bug.setPrivate(False, owner)
         self.assertEqual(
-            InformationType.UNEMBARGOEDSECURITY, bug.information_type)
+            InformationType.PUBLICSECURITY, bug.information_type)
 
     def test_private_sec_to_public_information_type(self):
         # A private security bug transitioning to public has the correct
         # information type.
         owner = self.factory.makePerson()
         bug = self.factory.makeBug(
-            information_type=InformationType.EMBARGOEDSECURITY, owner=owner)
+            information_type=InformationType.PRIVATESECURITY, owner=owner)
         with person_logged_in(owner):
             bug.transitionToInformationType(InformationType.PUBLIC, owner)
         self.assertEqual(InformationType.PUBLIC, bug.information_type)
@@ -962,7 +962,7 @@
 
     def test_transition_special_cased_for_ubuntu(self):
         # When a bug on ubuntu is transitioned to USERDATA from
         # EMBARGOEDSECURITY, the bug supervisor is not subscribed, and the
         # bug's subscribers do not change.
         # This is to protect ubuntu's workflow, which differs from the
         # Launchpad norm.
@@ -972,7 +972,7 @@
         ubuntu.setBugSupervisor(
             self.factory.makePerson(name='supervisor'), admin)
         bug = self.factory.makeBug(
-            information_type=InformationType.EMBARGOEDSECURITY,
+            information_type=InformationType.PRIVATESECURITY,
             distribution=ubuntu)
         bug = removeSecurityProxy(bug)
         initial_subscribers = bug.getDirectSubscribers()
@@ -773,14 +773,14 @@
     def test_setPillarOwnerSubscribedIfNoSecurityContact(self):
         # The pillar owner is subscribed if the security contact is not set
-        # and the bug is marked as EMBARGOEDSECURITY.
+        # and the bug is marked as PRIVATESECURITY.
 
         bug_owner = self.factory.makePerson(name='bugowner')
@@ -962,7 +962,7 @@
     def test_transition_special_cased_for_ubuntu(self):
         # When a bug on ubuntu is transitioned to USERDATA from
-        # EMBARGOEDSECURITY, the bug supervisor is not subscribed, and the
+        # PRIVATESECURITY, the bug supervisor is not subscribed, and the
         # bug's subscribers do not change.
         # This is to protect ubuntu's workflow, which differs from the

=== modified file 'lib/lp/bugs/model/tests/test_bugtask.py'